@@ -42,8 +42,8 @@
 static int handle_cmdline(int *argc, char ***argv);
 static char *read_line(int fd);
 
-static const char *progname;
-static const char *socketfile = ACPID_SOCKETFILE;
+const char *progname;
+const char *socketfile = ACPID_SOCKETFILE;
 static int max_events;
 
 static void
