@@ -332,9 +332,6 @@ daemonize(void)
 {
 	pid_t pid, sid;
 
-    /* already a daemon */
-    if ( getppid() == 1 ) return 0;
-
 	/* fork off the parent process */
 	pid = fork();
 	if (pid < 0) {
