@@ -23,11 +23,7 @@
 #ifndef ACPID_H__
 #define ACPID_H__
 
-#include <unistd.h>
 #include <syslog.h>
-#include <stdarg.h>
-#include <sys/types.h>
-#include <sys/stat.h>
 
 #define ACPI_PROCDIR 		"/proc/acpi"
 #define ACPID_EVENTFILE		ACPI_PROCDIR "/event"
@@ -39,6 +35,10 @@
 #define ACPID_LOCKFILE		"/var/lock/acpid"
 #define ACPID_MAX_ERRS		5
 
+/* ??? make these changeable by commandline option? */
+#define ACPID_INPUTLAYERDIR   "/dev/input"
+#define ACPID_INPUTLAYERFILES ACPID_INPUTLAYERDIR "/event*"
+
 #define PACKAGE 		"acpid"
 
 /*
@@ -46,16 +46,12 @@
  */
 extern int acpid_debug;
 extern int logevents;
-extern int non_root_clients;
+extern const char *progname;
+
 extern int acpid_log(int level, const char *fmt, ...);
 
-/*
- * event.c
- */
-extern int acpid_read_conf(const char *confdir);
-extern int acpid_add_client(int client, const char *origin);
-extern int acpid_cleanup_rules(int do_detach);
-extern int acpid_handle_event(const char *event);
-extern void acpid_close_dead_clients(void);
+extern int locked();
+
+extern void clean_exit_with_status(int status);
 
 #endif /* ACPID_H__ */
