@@ -122,6 +122,12 @@ acpid_read_conf(const char *confdir)
 
 		len = strlen(dirent->d_name);
 
+		/* skip "." and ".." */
+		if (strncmp(dirent->d_name, ".", sizeof(dirent->d_name)) == 0)
+			continue;
+		if (strncmp(dirent->d_name, "..", sizeof(dirent->d_name)) == 0)
+			continue;
+
 		/* skip any files that don't match the run-parts convention */
 		if (regexec(&preg, dirent->d_name, 0, NULL, 0) != 0) {
 			acpid_log(LOG_INFO, "skipping conf file %s/%s\n", 
